@@ -12,6 +12,7 @@
 #' @template param_store_backends
 #' @template param_encapsulate
 #' @template param_allow_hotstart
+#' @template param_clone
 #'
 #' @return [BenchmarkResult].
 #'
@@ -19,6 +20,7 @@
 #' The fitted models are discarded after the predictions have been scored in order to reduce memory consumption.
 #' If you need access to the models for later analysis, set `store_models` to `TRUE`.
 #'
+#' @template section_predict_sets
 #' @template section_parallelization
 #' @template section_progress_bars
 #' @template section_logging
@@ -74,7 +76,8 @@
 #' ## Get the training set of the 2nd iteration of the featureless learner on penguins
 #' rr = bmr$aggregate()[learner_id == "classif.featureless"]$resample_result[[1]]
 #' rr$resampling$train_set(2)
-benchmark = function(design, store_models = FALSE, store_backends = TRUE, encapsulate = NA_character_, allow_hotstart = FALSE) {
+benchmark = function(design, store_models = FALSE, store_backends = TRUE, encapsulate = NA_character_, allow_hotstart = FALSE, clone = c("task", "learner", "resampling")) {
+  assert_subset(clone, c("task", "learner", "resampling"))
   assert_data_frame(design, min.rows = 1L)
   assert_names(names(design), permutation.of = c("task", "learner", "resampling"))
   design$task = list(assert_tasks(as_tasks(design$task)))
@@ -89,9 +92,15 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE, encaps
   # clone inputs
   setDT(design)
   task = learner = resampling = NULL
-  design[, "task" := list(list(task[[1L]]$clone())), by = list(hashes(task))]
-  design[, "learner" := list(list(learner[[1L]]$clone())), by = list(hashes(learner))]
-  design[, "resampling" := list(list(resampling[[1L]]$clone())), by = list(hashes(resampling))]
+  if ("task" %in% clone) {
+    design[, "task" := list(list(task[[1L]]$clone())), by = list(hashes(task))]
+  }
+  if ("learner" %in% clone) {
+    design[, "learner" := list(list(learner[[1L]]$clone())), by = list(hashes(learner))]
+  }
+  if ("resampling" %in% clone) {
+    design[, "resampling" := list(list(resampling[[1L]]$clone())), by = list(hashes(resampling))]
+  }
 
   # set encapsulation + fallback
   set_encapsulation(design$learner, encapsulate)
@@ -106,6 +115,7 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE, encaps
     )
   })
   n = nrow(grid)
+  lgr_threshold = map_int(mlr_reflections$loggers, "threshold")
 
   # set default mode
   set(grid, j = "mode", value = "train")
@@ -123,6 +133,7 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE, encaps
     hotstart_grid = pmap_dtr(grid, function(task, learner, resampling, iteration, ...) {
       if (!is.null(learner$hotstart_stack)) {
         # search for hotstart learner
+        learner = learner$clone()
         task_hashes = task_hashes(task, resampling)
         start_learner = get_private(learner$hotstart_stack)$.start_learner(learner, task_hashes[iteration])
       }
@@ -137,8 +148,9 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE, encaps
       }
       data.table(learner = list(learner), mode = mode)
     })
+
     # null hotstart stack to reduce overhead in parallelization
-    map(hotstart_grid$learner, function(learner) {
+    walk(hotstart_grid$learner, function(learner) {
       learner$hotstart_stack = NULL
       learner
     })
@@ -152,7 +164,7 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE, encaps
     res = mapply(workhorse,
       task = grid$task, learner = grid$learner, resampling = grid$resampling, iteration = grid$iteration,
       mode = grid$mode,
-      MoreArgs = list(store_models = store_models, lgr_threshold = lg$threshold, pb = pb),
+      MoreArgs = list(store_models = store_models, lgr_threshold = lgr_threshold, pb = pb),
       SIMPLIFY = FALSE, USE.NAMES = FALSE
     )
   } else {
@@ -161,7 +173,7 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE, encaps
     res = future.apply::future_mapply(workhorse,
       task = grid$task, learner = grid$learner, resampling = grid$resampling, iteration = grid$iteration,
       mode = grid$mode,
-      MoreArgs = list(store_models = store_models, lgr_threshold = lg$threshold, pb = pb),
+      MoreArgs = list(store_models = store_models, lgr_threshold = lgr_threshold, pb = pb),
       SIMPLIFY = FALSE, USE.NAMES = FALSE, future.globals = FALSE,
       future.scheduling = structure(TRUE, ordering = "random"), future.packages = "mlr3", future.seed = TRUE,
       future.stdout = future_stdout()
