@@ -16,6 +16,10 @@ test_that("DataBackendCbind", {
 
   x = b$missings(b$rownames, c("Petal.Width", "Petal.Length"))
   expect_equal(x, set_names(c(0L, 30L), c("Petal.Width", "Petal.Length")))
+
+
+  expect_equal(b$col_hashes, c(b1$col_hashes, b2$col_hashes)[setdiff(b$colnames, b$primary_key)])
+
 })
 
 test_that("issue #124", {
@@ -45,6 +49,10 @@ test_that("cbind backends with same columns", {
   data = b$head(Inf)
   expect_false(anyMissing(data$Petal.Width))
   expect_true(allMissing(data$Sepal.Width))
+
+  expect_equal(b$col_hashes, insert_named(b1$col_hashes, b2$col_hashes)[setdiff(b$colnames, b$primary_key)])
+
+
 })
 
 test_that("Backends with different rows", {
@@ -60,6 +68,9 @@ test_that("Backends with different rows", {
   expect_set_equal(b$rownames, 1:20)
 
   expect_data_table(b$head(Inf), nrows = 20, ncols = 6)
+
+  expect_equal(b$col_hashes, c(b1$col_hashes, b2$col_hashes)[setdiff(b$colnames, b$primary_key)])
+
 })
 
 test_that("Backends with mixed data_formats", {
