@@ -49,7 +49,7 @@ test_that("Rows return ordered with multiple order cols", {
   task$col_roles$order = c("Petal.Length", "Petal.Width")
   expect_equal(task$col_roles$order, c("Petal.Length", "Petal.Width"))
 
-  x = task$data()
+  x = task$data(ordered = TRUE)
   expect_numeric(x$Petal.Length, sorted = TRUE, any.missing = FALSE)
 
   expect_true(x[, is.unsorted(Petal.Width)])
@@ -104,10 +104,21 @@ test_that("Task rbind", {
   learner = lrn("classif.rpart")
   learner$train(task)
   expect_prediction(predict(learner, iris, predict_type = "<Prediction>"))
+
+  # merge factor levels
+  task = tsk("penguins")
+  data = task$data(1)
+  data$sex = factor("unsure", levels = c("male", "female", "unsure"))
+  task$rbind(data)
+  expect_equal(task$levels("sex")[[1]], c("female", "male", "unsure"))
+  expect_equal(task$col_info[list("sex"), fix_factor_levels], TRUE)
 })
 
 test_that("Task cbind", {
   task = tsk("iris")
+
+  iris_col_hashes = task$col_hashes
+
   # expect_error(task$cbind(task), "data.frame")
   data = cbind(data.frame(foo = 150:1), data.frame(..row_id = task$row_ids))
   task$cbind(data)
@@ -115,6 +126,8 @@ test_that("Task cbind", {
   expect_equal(task$ncol, 6L)
   expect_names(task$feature_names, must.include = "foo")
 
+  expect_equal(iris_col_hashes, task$col_hashes[names(iris_col_hashes)])
+
   data = data.frame(bar = runif(150))
   task$cbind(data)
   expect_task(task)
@@ -141,10 +154,13 @@ test_that("Task cbind", {
   backend = data.table(x = runif(120))
   task$cbind(backend)
 
+  expect_equal(iris_col_hashes, task$col_hashes[names(iris_col_hashes)])
+
   # cbind 0-row data (#461)
   task = tsk("iris")$filter(integer())
   task$cbind(data.frame(x = integer()))
   expect_set_equal(c(task$target_names, task$feature_names), c(names(iris), "x"))
+
 })
 
 test_that("cbind/rbind works", {
@@ -427,3 +443,44 @@ test_that("column labels", {
     tolower(c(task$target_names, task$feature_names))
   )
 })
+
+test_that("set_levels", {
+  task = tsk("penguins")
+
+  new_lvls = c("male", "female", "missing")
+  task$set_levels(list(sex = new_lvls))
+
+  tab = task$col_info[list("sex")]
+  expect_equal(tab$levels[[1]], new_lvls)
+  expect_equal(tab$fix_factor_levels[[1]], TRUE)
+  expect_equal(levels(task$data(1)$sex), new_lvls)
+  expect_equal(levels(task$head()$sex), new_lvls)
+
+
+  new_lvls = c("female", "nothing")
+  task$set_levels(list(sex = new_lvls))
+
+  tab = task$col_info[list("sex")]
+  expect_equal(tab$levels[[1]], new_lvls)
+  expect_equal(tab$fix_factor_levels[[1]], TRUE)
+  expect_equal(as.integer(task$data(1)$sex), NA_integer_)
+  expect_equal(as.integer(task$head(1)$sex), NA_integer_)
+  expect_equal(levels(task$data(1)$sex), new_lvls)
+  expect_equal(levels(task$head(1)$sex), new_lvls)
+})
+
+test_that("special chars in feature names (#697)", {
+  prev = options(mlr3.allow_utf8_names = FALSE)
+  on.exit(options(prev))
+
+  expect_error(
+    TaskRegr$new("test", data.table(`%^` = 1:3, t = 3:1), target = "t"),
+    "comply"
+  )
+  options(mlr3.allow_utf8_names = TRUE)
+
+  expect_error(
+    TaskRegr$new("test", data.table(`%^` = 1:3, t = 3:1), target = "t"),
+    "special character"
+  )
+})
