@@ -47,8 +47,8 @@ test_that("evaluate / resample", {
   resampling = rsmp("cv", folds = 3)
 
   rr = suppressMessages(suppressWarnings(resample(task, disable_encapsulation(learner), resampling)))
-  expect_true(all(map(private(rr)$.data$data$fact$learner_state, function(x) nrow(x$log)) == 0L))
+  expect_true(every(get_private(rr)$.data$data$fact$learner_state, function(x) nrow(x$log) == 0L))
 
   expect_silent(rr <- resample(task, enable_encapsulation(learner), resampling))
-  expect_true(all(map_lgl(private(rr)$.data$data$fact$learner_state, function(x) all(table(x$log$stage) == 2))))
+  expect_true(every(get_private(rr)$.data$data$fact$learner_state, function(x) all(table(x$log$stage) == 2)))
 })
