@@ -1,5 +1,3 @@
-context("fallback")
-
 test_that("train fails gracefully", {
   task = tsk("iris")
   learner = lrn("classif.debug", error_train = 1)
@@ -20,7 +18,7 @@ test_that("fail during train", {
   learner$fallback = lrn("classif.featureless")
   learner$train(task)
 
-  expect_is(learner$state$fallback_state$model, "classif.featureless_model")
+  expect_s3_class(learner$state$fallback_state$model, "classif.featureless_model")
   expect_null(learner$state$model)
   expect_number(learner$state$train_time, lower = 0)
 
@@ -34,8 +32,8 @@ test_that("fail during predict", {
   learner$fallback = lrn("classif.featureless")
   learner$train(task)
 
-  expect_is(learner$state$fallback_state$model, "classif.featureless_model")
-  expect_is(learner$state$model, "classif.debug_model")
+  expect_s3_class(learner$state$fallback_state$model, "classif.featureless_model")
+  expect_s3_class(learner$state$model, "classif.debug_model")
   expect_number(learner$state$train_time, lower = 0)
 
   expect_prediction(learner$predict(task))
